.. method:: __getitem__(index)

   Get the angle component at index.

   :arg index: The index of the component.
   :type index: int
   :return: The component value.
   :rtype: float

.. method:: __setitem__(index, value)

   Set the angle component at index.

   :arg index: The index of the component.
   :type index: int
   :arg value: The value to set.
   :type value: float
